is_command_available

Function is_command_available 

pub fn is_command_available(command: &str) -> bool
Check if a command is available in the system PATH

Errors

Returns false if the command is not found or if the check fails.